@@ -50,7 +50,7 @@ try:
 
     import asyncio, platform, psutil, socket, json, re
     import signal, shutil, termios, tty, select, fcntl
-    import subprocess, shlex
+    import subprocess, shlex, types
     from collections import Counter
     from pathlib import Path
     from datetime import datetime, timedelta
@@ -1088,7 +1088,14 @@ def shortcut_handler(text: str) -> bool:
     global _run
     if text and text[0] in shortcuts.keys():
         shortcut = shortcuts[text[0]]
-        if not shell_inject(f" {shortcut}\n"):
+        if isinstance(shortcut, (types.FunctionType, types.BuiltinFunctionType)):
+            try:  # Yay, arbitrary code goooooooo
+                shortcut()
+            except KeyboardInterrupt:
+                pass
+            except:
+                pass
+        elif not shell_inject(f" {shortcut}\n"):
             _run = [_shell, "-c", f'eval "{shortcut}"; exec {_shell}']
     else:
         shell_inject(text)
